OC.L10N.register(
    "notes",
    {
    "Notes" : "یادداشت‌ها",
    "Create new note" : "ایجاد یادداشت جدید",
    "More notes" : "یادداشت‌های بیشتر",
    "Reading notes from filesystem has failed." : "خواندن یادداشت‌ها از سیستم فایل با شکست مواجه شد.",
    "Error" : "خطا",
    "New note" : "یادداشت جدید",
    "Distraction-free notes and writing" : "یادداشت‌نویسی و نوشتن بدون حواس‌پرتی",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into apps ([Android](https://github.com/nextcloud/notes-android), [iOS](https://github.com/nextcloud/notes-ios), as well as [3rd-party apps](https://github.com/nextcloud/notes/wiki#3rd-party-clients) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "برنامه یادداشت‌ها یک اپلیکیشن یادداشت‌نویسی بدون حواس‌پرتی برای [نکست‌کلود](https://www.nextcloud.com/) است. این برنامه دسته‌بندی‌هایی برای سازماندهی بهتر ارائه می‌دهد و از قالب‌بندی با استفاده از نحو [مارک‌داون](https://en.wikipedia.org/wiki/Markdown) پشتیبانی می‌کند. یادداشت‌ها به‌عنوان فایل‌هایی در نکست‌کلود شما ذخیره می‌شوند، بنابراین می‌توانید آن‌ها را با هر کلاینتی از نکست‌کلود مشاهده و ویرایش کنید. علاوه بر این، یک [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) جداگانه امکان ادغام آسان در برنامه‌ها ([اندروید](https://github.com/nextcloud/notes-android)، [iOS](https://github.com/nextcloud/notes-ios)، و همچنین [برنامه‌های شخص ثالث](https://github.com/nextcloud/notes/wiki#3rd-party-clients) که دسترسی راحت به یادداشت‌های نکست‌کلود شما را فراهم می‌کنند) می‌دهد. ویژگی‌های دیگر شامل علامت‌گذاری یادداشت‌ها به‌عنوان موارد دلخواه است.",
    "Deleted {title}" : "{title} حذف شد",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["{number} یادداشت حذف شد","{number} یادداشت حذف شدند"],
    "Undo Delete" : "لغو حذف",
    "Note recovered" : "یادداشت بازیابی شد",
    "_Recovered {number} note_::_Recovered {number} notes_" : ["{number} یادداشت یازیابی شد","{number} یادداشت یازیابی شدند"],
    "There are unsaved notes. Leaving the page will discard all changes!" : "یادداشت‌های ذخیره‌نشده وجود دارد. خروج از صفحه باعث از دست رفتن تمام تغییرات می‌شود!",
    "New category" : "دسته‌بندی جدید",
    "Notes settings" : "تنظیمات یادداشت‌ها",
    "Please see Nextcloud server log for details." : "لطفاً برای جزئیات به لاگ سرور نکست‌کلود مراجعه کنید.",
    "Custom" : "سفارشی",
    "Rich text" : "متن غنی",
    "Plain text" : "متن ساده",
    "Preview" : "پیش‌نمایش",
    "Make the selection bold" : "انتخاب را پررنگ کنید",
    "Make the selection italic" : "انتخاب را مورب کنید",
    "Wrap the selection in quotes" : "انتخاب را در نقل‌قول قرار دهید",
    "The selection will be turned into monospace" : "انتخاب به تک‌فاصله تبدیل می‌شود",
    "Remove any styles from the selected text" : "هرگونه سبک را از متن انتخاب‌شده حذف کنید",
    "Makes the current line a list element" : "خط فعلی را به یک عنصر لیست تبدیل می‌کند",
    "Makes the current line a list element with a number" : "خط فعلی را به یک عنصر لیست شماره‌دار تبدیل می‌کند",
    "Toggle heading for current line" : "تغییر عنوان برای خط فعلی",
    "Set the current line as a big heading" : "خط فعلی را به عنوان بزرگ تنظیم کنید",
    "Insert link" : "درج پیوند",
    "Insert image" : "درج تصویر",
    "Switch between editor and viewer" : "جابه‌جایی بین ویرایشگر و نمایشگر",
    "Pick a notes folder" : "انتخاب پوشه یادداشت‌ها",
    "Set notes folder" : "تنظیم پوشه یادداشت‌ها",
    "General" : "عمومی",
    "Display" : "نمایش",
    "File extension" : "پسوند فایل",
    "For new notes" : "برای یادداشت‌های جدید",
    "Custom file extension" : "پسوند فایل سفارشی",
    "Files" : "فایل‌ها",
    "Notes folder" : "پوشه یادداشت‌ها",
    "Mobile apps" : "برنامه‌های موبایل",
    "Shortcuts" : "میانبرها",
    "_Delete category \"{category}\" and its {count} note?_::_Delete category \"{category}\" and its {count} notes?_" : ["دسته‌ی \"{category}\" و {count} یادداشت آن حذف شود؟","دسته‌ی \"{category}\" و {count} یادداشت آن حذف شوند؟"],
    "Delete category" : "حذف دسته‌بندی",
    "Delete" : "حذف",
    "Cancel" : "لغو",
    "All notes" : "همه یادداشت‌ها",
    "Categories" : "دسته‌بندی‌ها",
    "Rename category" : "تغییر نام دسته‌بندی",
    "Create a sample note with Markdown" : "ایجاد یک یادداشت نمونه با مارک‌داون",
    "No notes yet" : "هنوز یادداشتی وجود ندارد",
    "Select an image" : "انتخاب یک تصویر",
    "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "نمی‌توانید تصاویر خارج از پوشه یادداشت‌های خود را انتخاب کنید. پوشه یادداشت‌های شما: {folder}",
    "Wrong image" : "تصویر اشتباه",
    "The file was not uploaded. Check your server logs." : "فایل آپلود نشد. گزارش‌های سرور خود را بررسی کنید.",
    "Upload image" : "آپلود تصویر",
    "Android" : "اندروید",
    "iPhone and iPad" : "آیفون و آیپد",
    "Rich text editor" : "ویرایشگر متن غنی",
    "You can now switch to use the easy to use and distraction free rich text editor. It allows you to edit notes without seeing any Markdown marks." : "اکنون می‌توانید به ویرایشگر متن غنی آسان و بدون حواس‌پرتی تغییر دهید. این امکان به شما اجازه می‌دهد بدون دیدن نشانه‌های مارک‌داون، یادداشت‌ها را ویرایش کنید.",
    "This option can also be changed later on in the Notes app settings." : "این گزینه را می‌توانید بعداً در تنظیمات برنامه یادداشت‌ها تغییر دهید.",
    "Keep plain Markdown editor" : "نگه‌داشتن ویرایشگر ساده مارک‌داون",
    "Use rich editor" : "استفاده از ویرایشگر غنی",
    "Remove from favorites" : "حذف از موارد دلخواه",
    "Add to favorites" : "افزودن به موارد دلخواه",
    "Error while renaming note." : "خطا در تغییر نام یادداشت.",
    "Error during preparing note for deletion." : "خطا در آماده‌سازی یادداشت برای حذف.",
    "Share" : "اشتراک‌گذاری",
    "Change category" : "تغییر دسته‌بندی",
    "Rename" : "تغییر نام",
    "Rename note" : "تغییر نام یادداشت",
    "Delete note" : "حذف یادداشت",
    "Error from Nextcloud server: {msg}" : "خطا از سرور نکست‌کلود: {msg}",
    "The note has been changed in another session. Please choose which version should be saved." : "یادداشت در جلسه دیگری تغییر کرده است. لطفاً نسخه‌ای که باید ذخیره شود را انتخاب کنید.",
    "Use version from server" : "استفاده از نسخه سرور",
    "Use current version" : "استفاده از نسخه فعلی",
    "Empty note" : "یادداشت خالی",
    "Write …" : "بنویسید …",
    "CTRL + /" : "CTRL + /",
    "Edit" : "ویرایش",
    "Exit full screen" : "خروج از تمام‌صفحه",
    "Full screen" : "تمام‌صفحه",
    "Note is read-only. You cannot change it." : "یادداشت فقط خواندنی است. نمی‌توانید آن را تغییر دهید.",
    "Save failed. Click to retry." : "ذخیره‌سازی ناموفق بود. برای تلاش مجدد کلیک کنید.",
    "Update conflict. Click for resolving manually." : "تضاد به‌روزرسانی. برای حل دستی کلیک کنید.",
    "Sharing is not available right now." : "اشتراک‌گذاری در حال حاضر در دسترس نیست.",
    "Failed to load the sharing sidebar." : "بارگیری نوار کناری اشتراک‌گذاری ناموفق بود.",
    "Unable to load the selected note for sharing." : "امکان بارگیری یادداشت انتخاب‌شده برای اشتراک‌گذاری وجود ندارد.",
    "Today" : "امروز",
    "Yesterday" : "دیروز",
    "This week" : "این هفته",
    "Last week" : "هفته گذشته",
    "This month" : "این ماه",
    "Last month" : "ماه گذشته",
    "Search for notes" : "جستجوی یادداشت‌ها",
    "Loading …" : "در حال بارگیری …",
    "Find in all categories" : "جستجو در همه دسته‌بندی‌ها",
    "Write down your thoughts without any distractions." : "افکار خود را بدون هیچ حواس‌پرتی بنویسید.",
    "Use Markdown markups to style your text." : "از نشانه‌گذاری مارک‌داون برای قالب‌بندی متن خود استفاده کنید.",
    "Organize your notes in categories." : "یادداشت‌های خود را در دسته‌بندی‌ها سازماندهی کنید.",
    "Start writing a note by clicking on “{newnote}”." : "با کلیک روی “{newnote}” نوشتن یک یادداشت را شروع کنید.",
    "Note not found." : "یادداشت یافت نشد.",
    "Note is locked." : "یادداشت قفل شده است.",
    "Insufficient storage." : "فضای ذخیره‌سازی ناکافی است.",
    "See JavaScript console and server log for details." : "برای جزئیات، کنسول جاوااسکریپت و لاگ سرور را بررسی کنید.",
    "Updating settings has failed." : "به‌روزرسانی تنظیمات انجام نشد.",
    "Fetching notes for dashboard has failed." : "دریافت یادداشت‌ها برای داشبورد انجام نشد.",
    "Fetching notes has failed." : "دریافت یادداشت‌ها انجام نشد.",
    "Fetching note {id} has failed." : "دریافت یادداشت {id} انجام نشد.",
    "Refreshing note {id} has failed." : "بازخوانی یادداشت {id} انجام نشد.",
    "Renaming note {id} has failed." : "تغییر نام یادداشت {id} انجام نشد.",
    "Creating new note has failed." : "ایجاد یادداشت جدید انجام نشد.",
    "Saving note {id} has failed." : "ذخیره‌سازی یادداشت {id} انجام نشد.",
    "Updating title for note {id} has failed." : "به‌روزرسانی عنوان یادداشت {id} انجام نشد.",
    "Undo delete has failed for note {title}." : "لغو حذف برای یادداشت {title} انجام نشد.",
    "Deleting note {id} has failed." : "حذف یادداشت {id} انجام نشد.",
    "Toggling favorite for note {id} has failed." : "تغییر وضعیت موردعلاقه برای یادداشت {id} انجام نشد.",
    "Updating the note's category has failed. Is the target directory writable?" : "به‌روزرسانی دسته‌بندی یادداشت انجام نشد. آیا پوشه مقصد قابل نوشتن است؟",
    "Updating the category for note {id} has failed." : "به‌روزرسانی دسته‌بندی برای یادداشت {id} انجام نشد.",
    "Renaming category \"{category}\" has failed." : "تغییر نام دسته‌بندی \"{category}\" انجام نشد.",
    "Deleting category \"{category}\" has failed." : "حذف دسته‌بندی \"{category}\" انجام نشد.",
    "Uncategorized" : "بدون دسته‌بندی",
    "Sample note" : "یادداشت نمونه",
    "15 January 2021, via Nextcloud Notes" : "۱۵ ژانویه ۲۰۲۱، از طریق نکست‌کلود یادداشت‌ها",
    "Me, you, and all our friends!" : "من، تو و همه دوستانمان!",
    "Tasks" : "وظایف",
    "Write nice todo lists" : "لیست کارهای خوب بنویسید",
    "Buy Fries" : "سیب‌زمینی سرخ‌کرده بخرید",
    "Birthdays" : "تولدها",
    "Jen, in three days!" : "جن، سه روز دیگر!",
    "Moss, 21.03.1973" : "ماس، ۲۱.۰۳.۱۹۷۳",
    "Roy, 1979" : "روی، ۱۹۷۹",
    "Review Steps" : "مراحل بررسی",
    "Turn PC off" : "کامپیوتر را خاموش کنید",
    "Turn PC on" : "کامپیوتر را روشن کنید",
    "Then call IT" : "سپس با IT تماس بگیرید",
    "Quotes" : "نقل‌قول‌ها",
    "Nextcloud, a safe home for all your data" : "نکست‌کلود، خانه‌ای امن برای تمام داده‌های شما",
    "Development Mode" : "حالت توسعه",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "به نظر می‌رسد که برنامه یادداشت‌ها از یک منبع توسعه نصب شده است. لطفاً آن را از <a href=\"%1$s\">فروشگاه رسمی نکست‌کلود</a> نصب کنید. اگر می‌خواهید برنامه یادداشت‌ها را خودتان بسازید، لطفاً <a href=\"%2$s\">دستورالعمل‌های توسعه‌دهنده</a> را دنبال کنید."
},
"nplurals=2; plural=(n > 1);");
